[CmdletBinding()]
Param(
  [Parameter(Mandatory=$false,Position=1,HelpMessage="Configuration file")]
   [string]$configurationFile = "Configuration.ps1"
)

Import-Module WebAdministration

function Load-Snapins()
{
  $snapinsToCheck = @("WDeploySnapin3.0")
  $currentSnapins = Get-PSSnapin

  $snapinsToCheck | ForEach-Object `
    {$snapin = $_;
      if(($CurrentSnapins | Where-Object {$_.Name -eq "$snapin"}) -eq $null)
      {
         Write-Host "$snapin snapin not found, loading it"
         Add-PSSnapin $snapin
         Write-Host "$snapin snapin loaded"
      }
    }

  $wdeploySnapin = Get-PSSnapin -Name "WDeploySnapin3.0" -ErrorAction SilentlyContinue
  if (!$wdeploySnapin) 
  {
    Write-Host -foregroundcolor Red "Microsoft Web Deploy snapin was not found and could not be loaded. Microsoft Web Deploy 3.0 is required for this installation, please download Web Deploy from 
    http://www.iis.net/downloads/microsoft/web-deploy and try again. The installation will now exit"
    exit
  }
}

Load-Snapins

. ./$configurationFile

Write-Host -foregroundcolor Green Creating application pool $appPoolName

$ErrorActionPreference = "SilentlyContinue"
$appPoolPath = "IIS:\AppPools\$appPoolName"
$pool = Get-Item $appPoolPath
$ErrorActionPreference = "Continue" 
if ($pool -ne $null) 
{
  Write-Host -Foregroundcolor Yellow Application pool $appPoolName already exists - not making changes to it.
  $poolExists = $true
} else
{
  $poolExists = $false
  $appPool = New-Item $appPoolPath
  $appPool.ManagedRuntimeVersion = "v4.0"
  $appPool.ManagedPipelineMode = "Integrated"
  $appPool.ProcessModel.IdentityType = 2 # Change identity to Network Service
  $appPool | Set-Item
} 

if ($customAppPoolCredentials -and !$poolExists) 
{
  $appPool = Get-Item $appPoolPath
  $appPool.ProcessModel.UserName = $appPoolUser
  $passwordsMatch = $false
  while (!$passwordsMatch)
  {
    $appPoolPasswd = Read-Host -AsSecureString "Please enter password for $appPoolUser"
    $appPoolPasswd2 = Read-Host -AsSecureString "Please verify password for $appPoolUser"
    $appPoolPasswd = [System.Runtime.InteropServices.Marshal]::PtrToStringAuto([System.Runtime.InteropServices.Marshal]::SecureStringToBSTR($appPoolPasswd))
    $appPoolPasswd2 = [System.Runtime.InteropServices.Marshal]::PtrToStringAuto([System.Runtime.InteropServices.Marshal]::SecureStringToBSTR($appPoolPasswd2))
    if ($appPoolPasswd -eq $appPoolPasswd2)
    {
      $passwordsMatch = $true
    } else
    {
      Write-Host -foregroundcolor Yellow "Passwords do not match, please try again"
    }
  }
  $appPool.ProcessModel.Password = $appPoolPasswd
  $appPoolPasswd = $null # Just to be on the safe side
  $appPoolPasswd2 = $null
  $appPool.ProcessModel.IdentityType = 3  # Change identity type to custom account
  $appPool | Set-Item
}

Write-Host -foregroundcolor Green Deploying QPR ProcessAnalyzer Service

$pathExists = Test-Path $logFilePath
if (!$pathExists)
{
  New-Item -path $logFilePath -type Directory
}

$pathExists = Test-Path $licenseFilePath
if (!$pathExists)
{
  New-Item -path $licenseFilePath -type Directory
}


$dirSeparatorIncluded = $logFilePath.EndsWith("\")
if ($dirSeparatorIncluded)
{
  $logFileLocation = "$logFilePath$logFileName" 
  $paLogFilePath = "$logFilePath$paLogFileNAme" 
} else
{
  $logFileLocation = "$logFilePath\$logFileName"
  $paLogFilePath = "$logFilePath\$paLogFileNAme"
}

$dirSeparatorIncluded = $licenseFilePath.EndsWith("\")
if ($dirSeparatorIncluded)
{
  $licenseFileLocation = "$licenseFilePath$licenseFileName"  
} else
{
  $licenseFileLocation = "$licenseFilePath\$licenseFileName"
}


$deployParameters = @{
  DBConnectionString = "$DBConnectionString"
  ApplicationPath = "$appPath"
  ServiceLogFilePath = "$logFileLocation"
  BindingsConfigSource = "$bindingsConfigSource"
  PALogFilePath = "$paLogFilePath"
  SupportLoadBalancer = "$supportLoadBalancer"
  ActivationEMSAddress= "$activationEMSAddress"
  ActivUserFirstName = "$activUserFirstName"
  ActivUserLastName = "$activUserLastName"
  ActivUserEmail = "$activUserEmail"
  LicenseFilePath = "$licenseFileLocation"
  ProductActivationCode = "$productActivationCode"
  ResponsePollingInterval = "$responsePollingInterval"
  ServerGroupPA = "$serverGroupPA"
  ServerGroupMD = "$serverGroupMD"
  ServerGroupMEA = "$serverGroupMEA"
}

Restore-WDPackage (Resolve-Path('PA_Deploy.zip')) -Parameters $deployParameters

Write-Host -foregroundcolor Green Changing $appPath to use application pool $appPool.name
$appPool = Get-Item $appPoolPath
$sitePath = "IIS:\Sites\$appPath"
Set-ItemProperty -path $sitePath -name applicationPool -value $appPool.Name -Force